# PerfectoActions
[![Downloads](https://pepy.tech/badge/perfectoactions)](https://pepy.tech/project/perfectoactions)

With PerfectoActions, you can create maintenance scripts that handle the cleanup, reboot, reservation, and retrieval of network settings in parallel and across all or specific devices in the Perfecto lab. In addition, you can set up scheduling for these scripts to run at the desired interval, depending on the devices involved. You can also view or delete old media repository items and list all or specific users automatically. Device manufacturers that do not support auto-connect on reboot are skipped automatically.
This non-flash, non-native, multi-threaded solution replaces the following Perfecto native automation commands: clean device, reboot device, and get network settings.

Kindly refer to the Official documentation available here: https://developers.perfectomobile.com/pages/viewpage.action?pageId=50922763



<img src="https://github.com/PerfectoMobileSA/Device_actions_reporter/blob/master/docs/new/1.png" height="360" width="760"/>   